@@ -1,6 +1,10 @@
 """Common exceptions."""
 
 
+class ResponseMismatchError(Exception):
+    """Exception raised when request and response ID don't match."""
+
+
 class LimeSurveyError(Exception):
     """Basic exception raised by LimeSurvey."""
 
